import React from "react";

import DefaultLoadingComponent from "./CustomLoading";
import { ErrorComponent as DefaultErrorComponent, ErrorCodes } from "@gooddata/react-components";

export const defaultGetLoadingComponentProps = () => ({});
export const defaultGetErrorComponentProps = error => {
    if (error) {
        return {
            code: error.code,
            message: error.message,
        };
    }
    return {
        code: ErrorCodes.APP_NO_DATA.toString(),
        message: "No data",
    };
};

const ResourceState = ({
    children,
    source,
    LoadingComponent = DefaultLoadingComponent,
    getLoadingComponentProps = defaultGetLoadingComponentProps,
    ErrorComponent = DefaultErrorComponent,
    getErrorComponentProps = defaultGetErrorComponentProps,
}) => {
    const { isLoading, error, data } = source;
    if (isLoading) {
        return <LoadingComponent {...getLoadingComponentProps()} />;
    }
    if (error) {
        return <ErrorComponent {...getErrorComponentProps(error)} />;
    }
    if (!data) {
        return <ErrorComponent {...getErrorComponentProps(error)} />;
    }
    return children(data);
};

export default ResourceState;
