import React, { useState, useEffect, useCallback } from "react";
import sdk from "@gooddata/gooddata-js";
import AuthContext from "./AuthContext";
import { defaultSourceState } from "../utils";

const getUser = async () => {
    const isLoggedIn = await sdk.user.isLoggedIn();
    if (!isLoggedIn) {
        throw new Error("Unauthorized");
    }
    return sdk.user.getAccountInfo();
};

export const AuthProvider = ({ children }) => {
    const [userState, setUserState] = useState({ ...defaultSourceState });
    useEffect(() => {
        getUser()
            .then(account => {
                setUserState({ isLoading: false, error: null, data: account });
            })
            .catch(error => {
                setUserState({ isLoading: false, error, data: null });
            });
    }, []);

    const login = useCallback(async (username, password) => {
        setUserState({ isLoading: true, error: null, data: null });
        try {
            const user = await sdk.user.login(username, password);
            setUserState({ isLoading: false, error: null, data: user });
        } catch (error) {
            setUserState({ isLoading: false, error, data: null });
        }
    }, []);

    const logout = useCallback(async () => {
        setUserState({
            isLoading: true,
            error: null,
            data: null,
        });
        await sdk.user.logout();
        setUserState({
            isLoading: false,
            error: null,
            data: null,
        });
    }, []);

    return <AuthContext.Provider value={{ ...userState, login, logout }}>{children}</AuthContext.Provider>;
};

export default AuthProvider;
